@@ -2,6 +2,7 @@
 #include "controller.h"
 #include "youtube.h"
 #include "downloadmanager.h"
+#include "folderlistmodel.h"
 #include <QtGui/QApplication>
 #include <QDeclarativeContext>
 #include <QtDeclarative>
@@ -29,6 +30,8 @@ int main(int argc, char *argv[])
     context->setContextProperty("DownloadManager", &dm);
     context->setContextProperty("YouTube", &yt);
 
+    qmlRegisterType<QDeclarativeFolderListModel>("Models",1,0,"FolderListModel");
+
 #ifdef Q_WS_MAEMO_5
 //    viewer.engine()->addImportPath(QString("/opt/qtm11/imports"));
     viewer.engine()->setOfflineStoragePath("/home/user/.config/cutetube");
