@@ -126,7 +126,8 @@ function setDefaultSettings() {
                     [ "downloadStatus", "Paused"],
                     [ "downloadPath", "/home/user/MyDocs/.cutetube/"],
                     [ "screenOrientation", "Automatic" ],
-                    [ "mediaPlayer", "Media Player"] ];
+                    [ "mediaPlayer", "Media Player"],
+                    [ "searchOrder", "Date"] ];
 
     for (var i = 0; i < settings.length; i++) {
         var setting = settings[i][0];
@@ -234,11 +235,10 @@ function clearSearches() {
 function addVideoToArchive(video) {
     /* Add a new video to the archive */
 
-    removeStoredDownload(video);
     var db = getDatabase();
     var res = "";
     db.transaction(function(tx) {
-                       var rs = tx.executeSql('INSERT OR REPLACE INTO archive VALUES (?, ?, ?, ?, ?);', [ video.filePath, video.title, video.thumbnail, video.quality, 1 ]);
+                       var rs = tx.executeSql('INSERT OR REPLACE INTO archive VALUES (?, ?, ?, ?, ?);', [ video.filePath, video.title, video.thumbnail, video.quality, video.isNew ]);
                        if (rs.rowsAffected > 0) {
                            res = "OK";
                        }
@@ -251,16 +251,44 @@ function addVideoToArchive(video) {
     return res;
 }
 
+function getArchiveVideo(filePath) {
+    /* Retrieve the archive video with matching filePath from the database */
+
+    var db = getDatabase();
+    var res = "unknown";
+    db.transaction(function(tx) {
+                       var rs = tx.executeSql('SELECT * FROM archive WHERE filePath=?;', [ filePath ]);
+                       if (rs.rows.length > 0) {
+                           res = [ rs.rows.item(0).filePath, rs.rows.item(0).title, rs.rows.item(0).thumbnail, rs.rows.item(0).quality, rs.rows.item(0).isNew ];
+                       }
+                   }
+                   );
+    //console.log(res);
+    return res
+}
+
 function getAllArchiveVideos() {
     /* Retrieve all archive videos from the database */
 
     var db = getDatabase();
     var res = [];
+    var downloadPath = getSetting("downloadPath");
+    var path;
     db.transaction(function(tx) {
                        var rs = tx.executeSql('SELECT * FROM archive;');
                        if (rs.rows.length > 0) {
                            for(var i = 0; i < rs.rows.length; i++) {
-                               res[i] = [ rs.rows.item(i).filePath, rs.rows.item(i).title, rs.rows.item(i).thumbnail, rs.rows.item(i).quality, rs.rows.item(i).isNew ];
+                               path = Controller.archiveFileExists(rs.rows.item(i).filePath, downloadPath);
+                               if (path == "Not found") { // Check that the filepath exists
+                                   deleteVideoFromArchive(rs.rows.item(i).filePath);
+                               }
+                               else {
+                                   res[i] = [ rs.rows.item(i).filePath, rs.rows.item(i).title, rs.rows.item(i).thumbnail, rs.rows.item(i).quality, rs.rows.item(i).isNew ];
+                                   if (path != "Unchanged") {
+                                       res[i][0] = path;
+                                       editArchiveVideo(rs.rows.item(i).filePath, "filePath", path);
+                                   }
+                               }
                            }
                        }
                    }
@@ -269,13 +297,29 @@ function getAllArchiveVideos() {
     return res
 }
 
-function deleteVideoFromArchive(video) {
+function editArchiveVideo(filePath, attribute, newValue) {
+    /* Set the attribute of the video with matching filePath to newValue */
+
+    var attributes = [ "filePath", "title", "thumbnail", "quality", "isNew"];
+    var video = getArchiveVideo(filePath);
+    var modifiedVideo = {};
+    for (var i = 0; i < attributes.length; i++) {
+        modifiedVideo[attributes[i]] = video[i];
+    }
+    modifiedVideo[attribute] = newValue;
+    if (attribute == "filePath") {
+        deleteVideoFromArchive(filePath);
+    }
+    addVideoToArchive(modifiedVideo);
+}
+
+function deleteVideoFromArchive(filePath) {
     /* Delete the video with matching filePath from the archive */
 
     var db = getDatabase();
     var res = "";
     db.transaction(function(tx) {
-                       var rs = tx.executeSql('DELETE FROM archive WHERE filePath = ?;', [ video.filePath ]);
+                       var rs = tx.executeSql('DELETE FROM archive WHERE filePath = ?;', [ filePath ]);
                        if (rs.rowsAffected > 0) {
                            res = "OK";
                        }
@@ -307,13 +351,13 @@ function storeDownload(video) {
     return res;
 }
 
-function removeStoredDownload(video) {
+function removeStoredDownload(filePath) {
     /* Delete the video with matching filePath from the stored downloads */
 
     var db = getDatabase();
     var res = "";
     db.transaction(function(tx) {
-                       var rs = tx.executeSql('DELETE FROM downloads WHERE filePath = ?;', [ video.filePath ]);
+                       var rs = tx.executeSql('DELETE FROM downloads WHERE filePath = ?;', [ filePath ]);
                        if (rs.rowsAffected > 0) {
                            res = "OK";
                        }
@@ -329,23 +373,19 @@ function removeStoredDownload(video) {
 function restoreDownloads() {
     /* Restore all incomplete downloads */
 
+    var downloadPath = getSetting("downloadPath");
     var db = getDatabase();
     db.transaction(function(tx) {
                        var rs = tx.executeSql('SELECT * FROM downloads;');
                        if (rs.rows.length > 0) {
                            for(var i = 0; i < rs.rows.length; i++) {
                                var downloadItem = {
-                                   filePath: "/home/user/MyDocs/.cutetube/" + rs.rows.item(i).title.replace(/[@&~=\/:?#|]/g, "_") + ".mp4",
                                    title: rs.rows.item(i).title,
                                    thumbnail: rs.rows.item(i).thumbnail,
-                                   playerUrl:rs.rows.item(i).playerUrl.split("&")[0],
-                                   status: "Paused",
-                                   quality: getSetting("downloadQuality"),
-                                   convert: false,
-                                   bytesReceived: 0,
-                                   totalBytes: 100
+                                   playerUrl:rs.rows.item(i).playerUrl,
                                }
-                               downloadModel.appendDownload(downloadItem);
+                               removeStoredDownload(rs.rows.item(i).filePath);
+                               addDownload(downloadItem);
                            }
                        }
                    }
