@@ -24,39 +24,46 @@ void YouTube::setPlaybackQuality(const QString &quality) {
 }
 
 void YouTube::login(const QString &username, const QString &password) {
-    currentUser = username;
+    setCurrentUser(username);
     QNetworkRequest request(QUrl("https://www.google.com/accounts/ClientLogin"));
     request.setHeader(QNetworkRequest::ContentTypeHeader, "application/x-www-form-urlencoded");
     QByteArray loginData("Email=" + username.toAscii() + "&Passwd=" + password.toAscii() + "&service=youtube&source=cuteTube");
     QNetworkReply* reply = nam->post(request, loginData);
-    connect(reply, SIGNAL(finished()), this, SLOT(setAccessToken()));
+    connect(reply, SIGNAL(finished()), this, SLOT(checkLogin()));
 }
 
-void YouTube::setAccessToken() {
+void YouTube::checkLogin() {
     QNetworkReply* reply = qobject_cast<QNetworkReply*>(sender());
     if (!reply) {
-        currentUser = "";
+        setCurrentUser("");
         emit alert("Error obtaining access token");
         return;
     }
 
     QByteArray response = reply->readAll();
     QList<QByteArray> sp = response.split('=');
-    accessToken = sp.last().trimmed();
+    setAccessToken(sp.last().trimmed());
 
-    //    qDebug() << "accessToken is " << accessToken;
-
-    if (accessToken == "BadAuthentication") {
-        currentUser = "";
+    if (getAccessToken() == "BadAuthentication") {
+        setCurrentUser("");
         emit alert("Authentication failed");
     }
     else {
-        emit alert("You are signed in to YouTube as '" + currentUser + "'");
+        emit alert("You are signed in to YouTube as '" + getCurrentUser() + "'");
     }
-    emit currentUserChanged();
     reply->deleteLater();
 }
 
+void YouTube::setCurrentUser(const QString &user) {
+    currentUser = user;
+    emit currentUserChanged();
+}
+
+void YouTube::setAccessToken(const QByteArray &token) {
+    accessToken = token;
+    emit accessTokenChanged();
+}
+
 void YouTube::uploadVideo(const QString &filename, const QString &title, const QString &description, const QString &tags, const QString &category, const bool &isPrivate) {
 
     fileToBeUploaded = new QFile(filename);
@@ -83,7 +90,7 @@ void YouTube::uploadVideo(const QString &filename, const QString &title, const Q
     request.setRawHeader("Host", "uploads.gdata.youtube.com");
     request.setHeader(QNetworkRequest::ContentTypeHeader, "application/atom+xml; charset=UTF-8");
     request.setHeader(QNetworkRequest::ContentLengthHeader, xml.length());
-    request.setRawHeader("Authorization", "GoogleLogin auth=" + accessToken);
+    request.setRawHeader("Authorization", "GoogleLogin auth=" + accessToken.toAscii());
     request.setRawHeader("GData-Version", "2");
     request.setRawHeader("X-Gdata-Key", "key=" + developerKey);
     request.setRawHeader("Slug", filename.split("/").last().toAscii());
@@ -190,7 +197,7 @@ void YouTube::postRequest(const QUrl &url, const QByteArray &xml) {
     request.setRawHeader("Host", "gdata.youtube.com");
     request.setHeader(QNetworkRequest::ContentTypeHeader, "application/atom+xml");
     request.setHeader(QNetworkRequest::ContentLengthHeader, xml.length());
-    request.setRawHeader("Authorization", "GoogleLogin auth=" + accessToken);
+    request.setRawHeader("Authorization", "GoogleLogin auth=" + accessToken.toAscii());
     request.setRawHeader("GData-Version", "2");
     request.setRawHeader("X-Gdata-Key", "key=" + developerKey);
     QNetworkReply* reply = nam->post(request, xml);
@@ -221,7 +228,7 @@ void YouTube::deleteRequest(const QUrl &url) {
     QNetworkRequest request(url);
     request.setRawHeader("Host", "gdata.youtube.com");
     request.setHeader(QNetworkRequest::ContentTypeHeader, "application/atom+xml");
-    request.setRawHeader("Authorization", "GoogleLogin auth=" + accessToken);
+    request.setRawHeader("Authorization", "GoogleLogin auth=" + accessToken.toAscii());
     request.setRawHeader("GData-Version", "2");
     request.setRawHeader("X-Gdata-Key", "key=" + developerKey);
     QNetworkReply* reply = nam->deleteResource(request);
